Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IDex ¶
type IDex interface {
// SpotPrice returns the spot price of baseToken/quoteToken, it indicates how much of the quote token is needed to purchase one unit of the base token.
// If middleToken is not empty, it indicates the price of baseToken/middleTokens/quoteToken.
// Get history spot price by specify blockNumber in call opts , if blockNumber is nil, it will return the latest spot price.
SpotPrice(opts *bind.CallOpts, baseToken, quoteToken string, middleTokens ...string) (*decimal.Decimal, error)
// Liquidity returns the liquidity of the pair.
Liquidity(opts *bind.CallOpts, baseToken, quoteToken string) (*decimal.Decimal, *decimal.Decimal, error)
}
Click to show internal directories.
Click to hide internal directories.